Description: Обяви . Работа . Апартаменти . Къщи . Наеми . Автомобили . Коли . Камиони . Екскурзии . Почивки . Заведения . Обучения . Курсове . GSM . Електроника . Компютри . Офис техника . Машини . инструменти . ..
Keywords: Регистрация,Registratsia,alo,alo,realestates,realestates

Към началната страница
Вход в сайта »
Важно!
Вие имате право само на един акаунт в сайта.
При регистриране на повече от един акаунт администраторът си запазва правото да изтрие всички ваши акаунти, съгласно общите условия на сайта.

# Регистрация в alo.bg и realestates.bg

Всички параметри, означени със звездичка (*), са задължителни.

потребителско име*: | позволени символи abc..xyz, 0-9, точка, тире, долна черта | Вход в сайта » Забравена парола »
парола*: | позволени символи abc..xyz, 0-9, точка, тире, долна черта
повторете паролата*: | позволени символи abc..xyz, 0-9, точка, тире, долна черта
Email*: | Валиден Email (yourname@domain.com)
въведи сбора от числата*: | =
условия за регистрация: | Общи Правила и Условия за ползване на сайта за обяви alo.bg Моля, прочетете внимателно настоящите Общи условия, преди да използвате сайта alo.bg. Тези Общи условия уреждат отношенията между АЛО.БГ ЕООД, собственик на сайта alo.bg (наричан по-долу за краткост alo.bg), и лицата ползватели на услугите на този сайт. Използването на сайта alo.bg по какъвто и да е начин означава, че Потребителят се е запознал и съгласил с Общите условия и всички последващи промени в тях, което го обвързва със силата на договор, който се задължава да спазва. В случай че не сте съгласни с всички Общи условия по-долу, моля не използвайте този сайт. I. Основни понятия 1. По смисъла на настоящите Общи условия изброените понятия са използвани със следното значение: 1.1. „ПОТРЕБИТЕЛ“ е всяко физическо или юридическо лице, което използва някоя от услугите на сайта. Лица, ненавършили 18 години, следва да използват сайта под надзора на родител, попечител или настойник. alo.bg има право по свое усмотрение да ограничи достъпа до част от съдържанието на сайта на лица, ненавършили 18 години. 1.2. „УСЛУГА/И“ на сайта включват: - достъп до информационни ресурси/данни в сайта; - публикуване на обяви в сайта и във вестници АЛО; - създаване и персонализация на потребителски профили посредством регистрация; - възможност за изразяване на мнения и коментари по обявите; - писане на съобщения към обяви; - абониране за нови обяви; - промотиране на обяви; - достъп до информацията в печатните издания на вестници АЛО; - други действия на потребителите, предоставени им чрез интерфейса на сайта. 1.3. „ПАРТНЬОР“ е всяко лице, с което alo.bg се намира в договорни отношения. 1.4. „ЗЛОНАМЕРЕНИ АТАКИ НА ТРЕТИ ЛИЦА“ – действия или бездействия на трети лица, които са в противоречие с правилата на Интернет етиката, в това число, но не само DoS (Denial of Service – претоварване на сървъра), проникване в сървъра, deface, кражба на данни и др. 1.5. „ТОП оферта“ - специална услуга на alo.bg, с която можете да направите обявата си по-забележима за останалите потребители на сайта. Обявата се показва на първо място след нейното публикуване, с по-голяма снимка и по-атрактивно оформление. Отбелязва се със знак, който я отличава от останалите обяви. 1.6. „VIP обява“ – специална услуга на alo.bg, с която можете да направите обявата си по-забележима за останалите потребители на сайта. Обявата се показва преди безплатните обяви (след ТОП офертите) и е с по-атрактивно оформление. Отбелязва се със знак, който я отличава от останалите обяви. 1.7. „Първа обява“ - специална услуга на alo.bg, която представлява промяна на датата на последна редакция на обявата и позиционирането и на първо място пред другите обяви със същия статут (безплатни, VIP или ТОП). II. Правила относно създаване на потребителски профили (акаунт, регистрация, профил): 2. За да бъдат публикувани обяви в сайта alo.bg, е необходима регистрация, която се извършва чрез попълване на електронен формуляр, в който потребителят следва да посочи валидна информация, като имена, имейл адрес, телефон и др. Потребителят гарантира, че данните, предоставени при регистрацията, са пълни и точни и при промяна ще ги актуализира своевременно. Тези данни се използват само за целите на услугите на alo.bg. 3. Чрез регистрацията си потребителят създава акаунт в сайта alo.bg, който може да използва чрез потребителско име и парола. Потребителят е длъжен да пази от разкриване и да не предоставя потребителското си име и парола за ползване от други потребители или трети лица и да уведомява alo.bg в случай на разкриване на паролата. Потребителят носи пълна отговорност за всички действия, които се извършват от него или от трето лице чрез използване на потребителското име и паролата. alo.bg не носи отговорност за вреди, настъпили за потребителя в резултат от неправомерно използване на потребителското име и паролата му от трети лица. 4. В случай че потребителят не желае да се регистрира в alo.bg, той може да публикува обяви в сайта чрез телефонно обаждане на колцентър. Повече информация за услугата може да видите тук: https://www.alo.bg/login.php 5. Всяко физическо лице, юридическо лице или група от лица, извършващи обща дейност, имат право на един потребителски профил в сайта alo.bg. 5.1. За група от лица, извършващи обща дейност, се считат: - Влизащи в сайта от един и същ компютър, офис, браузър или IP адрес. - Споделящи един и същ физически адрес, фирмена регистрация, адрес за кореспонденция, адрес за работа с клиенти. - Имащи обща контактна информация – телефони, email – и, скайп акаунти, уебсайтове и т.н. - За които имаме данни, че са свързани, и между които има явна или неявна договорка. 5.2. При наличие на два или повече профила на едно лице, профилите се редуцират до един по усмотрение на alo.bg. При изтриване се заличават всички съпътстващи профила данни - обяви, контактна информация и др. 5.3. По усмотрение на alo.bg се изтриват и профили, създадени за заобикаляне на ограничения, наложени от сайта. III. Правила относно публикуването и съдържанието на обявата: 6. Сайтът си запазва правото да изтрива без предупреждение обяви/коментари/съобщения: 6.1. Които съдържат телефонен номер, имейл адрес или други контактни данни в текста на обявата (с изключение на специалните полета) или приложения снимков материал. 6.2. Които съдържат всякакъв вид контактна информация в снимките към обявите или снимката (лого) на профила в рубрика "ЗАПОЗНАНСТВА, ЕСКОРТ". 6.3. Които съдържат снимки или изображения с порнографско съдържание. 6.4. Еднакви обяви в една и съща категория преди срокът на същите да е изтекъл. 6.5. Обяви с един и същи текст, публикувани в различни категории. 6.6. Които съдържат несъществуваща, недостоверна, некоректна или погрешна информация. 6.7. Които съдържат телефони с добавена стойност извън разрешените рубрики: "УСЛУГИ - ОКУЛТНИ", "ЗАПОЗНАНСТВА, ЕСКОРТ - ВИРТУАЛЕН СЕКС". Обяви, които съдържат телефони с добавена стойност в разрешените рубрики, задължително трябва да упоменат това в текста на обявата, както и тарифата им на таксуване. 6.8. Които не съответстват или частично не съответстват с конкретния раздел на сайта. 6.9. Които съдържат лични данни (ЕГН, копие от паспорт, лична карта или друго). 6.10. За които се получават множество жалби. 6.11. Които имат противозаконно, противоречащо на моралните норми, оскърбително текстово или графично съдържание. 6.12. Които съдържат политически материали с агитационни цели и др. 6.13. Които съдържат информация, включваща серийни номера на софтуерни продукти, както и всяка друга, за която нямат законно право. 6.14. Които съдържат информация, представляваща търговска, служебна или друга тайна. 6.15. Които съдържат линкове, специални символи, излишни интервали, точки и пр. препинателни знаци, набор на еднакви или безсмислени букви, а също така и текст, който не се отнася към съдържанието на обявата. 6.16. Без точно и детайлно описание на предлаганата стока, услуга, дейност или работа. 6.17. Които съдържат повече от един брой предлагани услуги или стоки, или съобщения от общ характер. 6.18. В които са попълнени неправилно задължителните полета. 6.19. С цена или характеристики, различни от упоменатите в обявата. 6.20. Със снимки или графика, които не съответстват на конкретното предложение, съдържащо се в текста на обявата. 6.21. Които по какъвто и да е начин нарушават авторските права или други права на интелектуална собственост. 6.22. Предлагащи стоки и услуги, обект на лицензиране, освен ако обявата не съдържа точна контактна информация за компанията и номера на лиценза на съответния продукт. (касае се за серийни номера на софтуер, незаконно препродаван от частни лица или фирми) 6.23. Предлагащи тютюневи изделия, алкохол (с изключение на бутиков/колекционерски), прекурсори, медикаменти с контролен режим, наркотични вещества и всякакви други вещества, използвани като техни заместители, човешки органи, опасни вещества, а също така стоки без необходимия сертификат, съответстващ на нормите на EC. 6.24. Обяви на Интернет магазини, в които не е упомената конкретната стока, предмет на обявата. 6.25. Със снимки или графика, съдържащи логотипове, реклама или идентификатори на други сайтове. 6.26. Които съдържат множество правописни грешки. 6.27. Които не са изписани на кирилица. Употребата на латински букви е допустима само за посочване на търговски марки и модели на продукти. 6.28. Които съдържат текст или отделни думи и части от думи с главни букви (Caps Lock). Пример: "ПРОДАВАМ НОВ фотоапарат NIKON”. 6.29. Обяви, които са ориентирани към събирането на информация за Потребителите. 6.30. Които съдържат неоригинални снимки в рубрика Запознанства. 6.31. Обяви за недвижими имоти, в които е посочен тип на подателя „Собственик“, при условие че публикуващият обявата не е реален собсвеник на имота. 6.32. Обяви, предлагащи продукт или услуга, които към момента не са актуални. 7. Изтриването на обяви и публикуването на същите като нови, с цел избутването им по-напред в списъците, не е позволено. 8. Заплащането за ВИП/ТОП обява НЕ гарантира публикуването на обявата в alo.bg, ако тя не отговаря на Общите условия. 9. Към всяка обява в alo.bg публикуващият потребител има право да прикачи до 15 снимки. Размерът на всяка снимка не трябва да надвишава 4 MB. 10. Снимките се преоразмеряват автоматично до максимални размери 900 х 700 пиксела, ако техните размери ги надвишават. За съкратен преглед на обявите сайтът автоматично изработва малки изображения. Към снимките се добавя воден знак с логото на сайта. 11. При публикуване на обяви за стоки втора употреба със снимка/и е задължително качването на поне една реална снимка на предлагания артикул. 12. alo.bg няма задължение да контролира съдържанието на обявите и рекламите, публикувани в сайта, както и да следи за нарушаване на авторските права и сродните права върху последните. 13. alo.bg има право по свое усмотрение, без предупреждение да налага санкции при констатирани нарушения на общите условия: 13.1. В случай на груби или повторни нарушения на даден потребител – изтриване на потребителския профил и добавянето на контактите му в забранителен списък, с цел превенция на повторна регистрация на същия в сайта alo.bg. 13.2. При потребителите на месечен абонамент (предплащащите пакет обяви над безплатните лимити): - за едно нарушение в рамките на текущия месец – изтриване на обявите, публикувани в нарушение на общите условия. - за второ нарушение в рамките на текущия месец – премахване на VIP абонамента и свързаните с него допълнителни услуги. - за три и повече нарушения в рамките на текущия месец – ограничаване на достъпа до сайта. 13.3. По усмотрение на alo.bg могат да се налагат и други ограничения. 13.4. При изтриване на обяви и потребителски профили, вследствие на нарушение на общите условия, не се възстановяват предплатени абонаменти, обяви или суми в потребителски портфейли. 14. alo.bg има право по свое усмотрение, без предупреждение да изтрива обяви, снимки, регистрации, коментари и съобщения, ако прецени, че предоставената в тях информация е невярна, неточна, непълна или цели недобронамерени действия към други лица, като суми по същите не се възтановяват, в случай че са били платени. 15. alo.bg има право по свое усмотрение, без предупреждение да деактивира и върне за корекция от публикуващия потребител обяви, които не са публикувани в категорията, за която се отнасят. 16. alo.bg има право по свое усмотрение и съгласно уговорки с трети лица да поставя рекламни банери и други рекламни материали навсякъде в сайта, включително и в пространството, заето от обявата, независимо дали тя е безплатна, или платена и без оглед на това дали банерът или рекламният материал е на конкурент на публикувалия обявата. IV. Отговорност и ограничение на отговорността: 17. Цялата информация на сайта се предоставя в съответствие с действащото българско законодателство, без гаранция от страна на alo.bg за нейната ненакърнимост и безопасност от злонамерени атаки на трети лица. 18. alo.bg не носи отговорност за субективните възприятия и интерпретация на точността, пълнотата и полезността на информационните ресурси на сайта. 19. alo.bg не е страна или посредник при взаимоотношенията на потребителите в сайта и не носи никаква отговорност за наличността и качеството на стоки и съдържанието на услуги, поставени на вниманието на потребителя чрез публикуваните обяви, електронни препратки, рекламни банери, снимки и др. Доколкото действията на тези трети лица не са под контрола на alo.bg, то същият не носи отговорност за противоправния характер на дейността на третите лица или за възникването, гарантирането, изпълнението, изменението и прекратяването на поети задължения и ангажименти във връзка с предлаганите от третите лица стоки и услуги, както и не отговаря за претърпени вреди и пропуснати ползи, произтекли от тези отношения. 20. alo.bg не носи отговорност за непредоставяне на услугите при настъпване на обстоятелства извън неговия контрол – в случаи на непреодолима сила, случайни събития, проблеми в глобалната мрежа Интернет и в предоставянето на услуги извън контрола на alo.bg, както и при случай на нерегламентиран достъп на трети лица във функционирането на информационната система или сървърите на alo.bg. 21. alo.bg не носи отговорност спрямо потребителя и трети лица за претърпени вреди и пропуснати ползи, настъпили вследствие прекратяването, спирането, променянето или ограничаването на услугите, изтриването, модифицирането, загубването, недостоверността, неточността или непълнотaта на съобщенията, обявите и рекламата, станали достъпни чрез сайта alo.bg. 22. alo.bg има право на обезщетение за всички вреди, разноски и претенции на трети лица, които са следствие от нарушение на тези общи условия и/или нерегламентирана употреба на услугите на сайта. 23. alo.bg не носи отговорност за достоверността и актуалността на публикуваните обяви и реклама. Потребителят (подателят на обява) или рекламодателят носи пълната отговорност за съдържанието на подадената от него обява или публикувана реклама, както пред сайта за обяви alo.bg, така и пред трети лица, в случаите на нарушаване на правилата на сайта, на законодателството на Република България, на авторските права или сродните му права, правото на собственост, на правата на търговска марка и знак, както и в случаите на причинени имуществени или морални щети и неудобства на трети лица. V. Конфиденциалност 24. alo.bg е администратор на лични данни, регистриран по Закона за защита на личните данни. 25. С факта на публикуване на лични данни от физическо лице се приема, че физическото лице е дало съгласието си за обработване на личните му данни, включително и да се предоставят на трети лица, при ограниченията и съгласно разпоредбите на ЗЗЛД. 26. Всеки потребител декларира, че е съгласен цялата информация, въведена от него в сайта, извън изрично посочената, да бъдат достъпни за останалите потребители. 27. В сайта се публикуват и обработват лични данни само ако те са предоставени доброволно от физическото лице. alo.bg не извършва проверка относно доброволността или верността на публикувани лични данни. В случай че в сайта се съдържат лични данни, които физическото лице не е предоставило доброволно, или лични данни, които не са достоверни, то следва да бъдем уведомени незабавно. 28. alo.bg може да предоставя събраната статистическа информация за посещаемостта на сайта на рекламодатели/рекламни агенции, които водят статистика за кликанията върху техните рекламни банери и линкове, да изготвя вътрешни статистики, както и за целите на директния маркетинг (своите и на Партньори). 28.1. С приемането на настоящите Общи условия Потребителят се съгласява с обработването на личните му данни за целите на директния маркетинг. 28.2. Потребителят има право да възрази срещу обработването на личните му данни за целите на директния маркетинг, като изпрати писмено съобщение до аlo.bg на посочения адрес или e-mail за контакти. 29. Промяна на лични данни, публикувани в сайта, е допустима само от лицето, за което се отнасят. 30. В качеството си на администратор на лични данни АЛО.БГ ЕООД се ангажира да: 30.1. Вземе технически мерки за защита срещу неразрешен достъп до лични данни на потребител на сайта; 30.2. Осигури техническа възможност за въвеждане, промяна, допълнение и изтриване на лични данни от потребител на сайта; 30.3. Спазва разпоредбите на ЗЗЛД и другите нормативни актове, приложими в Република България и относими към защитата и обработването на лични данни, при обработката на лични данни. 31. При регламентирано изискване, идентификационните данни и архивът с действията на Потребителя се предоставят на органите на МВР и съдебните власти в писмен или електронен вид. 32. При използване на сайта alo.bg има правото автоматично да запазва определена информация, която компютър или друго крайно устройство на потребителя изпраща към сървър на alo.bg във връзка с активността на потребителя. Информацията се съхранява в лог-файлове на сървъри на alo.bg и може да включва IP адреса на потребителя, дата и час, в който е посетена съответната страница от сайта, времето прекарано на нея и др. В допълнение alo.bg съхранява IP адреса на потребителя, както и всяка друга информация, необходима за идентифициране на потребителя, в случай на възникване на правен спор. 33. alo.bg изпраща към компютър или друго крайно устройство на потребителя кукита (cookies) – малки текстови файлове. 34. При предоставяне на услугите alo.bg обработва информация, подадена от крайното устройство на потребителя с цел: 34.1. Осигуряване на нормален и качествен достъп на потребителя до услугите с всички техни функционални възможности; 34.2. Проверка за наличността на скриптове, софтуерни приложения и настройки на крайното устройство на потребителя, необходими за нормалния достъп и ползване на услугите и информирането му за липсата на такива; 34.3. Проследяване и предотвратяване извършването на регистрация и използване на множество потребителски профили от едно лице и злоумишлени действия; 34.4. Реклама и проучване на предпочитанията на потребителите. 35. В използваните от alo.bg кукита (cookies) не се съхранява информация (лични данни), която да позволява идентифицирането на потребителя като физическо лице. 36. В използваните от alo.bg кукита (cookies) може да се съхранява информация за: 36.1. Индентификация на потребителя. 36.2. Последно посещавани рубрики, подрубрики, области, обяви. 36.3. Потребителски настройки. 37. Потребителят има право по всяко време да откаже съхраняването и/или достъпа до информацията, съхранена в използваното от него крайно устройство. Забраната и/или изтриването на кукитата (cookies) от страна на потребителя може да доведе до пълна или частична невъзможност на потребителя да достъпи до сайта alo.bg и/или услугите, до промяна или премахване на предварително зададени от него при предишни посещения в сайта настройки и/или до съществено влошаване на качеството на услугите, за което alo.bg не носи отговорност. 38. Кукита могат да бъдат инсталирани и от трети лица с цел рекламиране на стоки и услуги, които може да представляват интерес за потребителя по време на неговото посещение на сайта и другите уебсайтове. alo.bg няма достъп до или контрол върху използването на тези кукита. Тези кукита също събират информация за начина на ползване на сайта alo.bg, като например кой сайт е препратил потребителя към сайта alo.bg, кои интернет страници е посетил потребителя в сайта, информация за посещенията на потребителя в други сайтове, но не събират информация като имена, електронен пощенски адрес, друга информация за контакти или други лични данни, които биха могли да дадат възможност на трето лице да идентифицира потребителя или да се свърже с него. VI. Прекратяване на услуги в alo.bg 39. Деактивиране и изтриване на обяви и акаунти 39.1. След изтичане на валидността на обявите или след ръчното им деактивиране от потребителя, те остават на сървърите на alo.bg за срок от 6 месеца, след което биват изтрити безвъзвратно от автоматична система. 39.2. Потребителят може да изтрие обявите или регистрацията си във всеки един момент по негово желание. 39.3. Потребителски профили, в които не е влизано от повече от 1 година, се изтриват безвъзвратно от автоматична система. 39.3. Изтрити обяви и акаунти не се възстановяват. VII. Авторски права 40. Всички права на интелектуална собственост върху информационните ресурси и материали, публикувани на сайта, са обект на закрила по действащия Закон за авторското право и сродните му права, а нерегламентираното им използване представлява закононарушение и влече гражданска, административнонаказателна и наказателна отговорност в съответствие с действащото българско законодателство. VIII. Промени 41. alo.bg си запазва правото да извършва промени в настоящите Общи условия по всяко време, като своевременно публикува тези промени в сайта. За всички неуредени с настоящите Общи условия въпроси се прилага действащото българско законодателство. 42. alo.bg си запазва правото да добавя нови услуги, да премахва съществуващи услуги и да променя характеристиките на предоставяните услуги без предупреждение. 43. alo.bg си запазва правото да изпраща на своите потребители непоискани търговски съобщения, включително и чрез системата за размяна електронни съобщения между потребители, инкорпорирана в сайта, с цел да информира потребителите за нови услуги или за промяна в условията на предлаганите досега услуги в сайта. С приемането на настоящите Общи условия потребителят се съгласява да получава непоискани търговски съобщения от alo.bg. IX. Собственост 44. Сайтът alo.bg е собственост и се поддържа от фирма АЛО.БГ ЕООД. За повече информация и контакт с нас, пишете на посочения e-mail: info@alo.bg Дата: 21.08.2015 г.

﻿